@@ -388,8 +388,9 @@ class Path(Pattern):
         return request.url.path
 
     def strip_base(self, value: str) -> str:
-        value = value[len(self.base.value) :]
-        value = "/" + value if not value.startswith("/") else value
+        if self.base:
+            value = value[len(self.base.value) :]
+            value = "/" + value if not value.startswith("/") else value
         return value
 
 
@@ -499,13 +500,10 @@ class Data(ContentMixin, Pattern):
         return data
 
 
-def M(*patterns: Pattern, **lookups: Any) -> Pattern:
+def M(*patterns: Pattern, **lookups: Any) -> Optional[Pattern]:
     extras = None
 
     for pattern__lookup, value in lookups.items():
-        if not value:
-            continue
-
         # Handle url pattern
         if pattern__lookup == "url":
             extras = parse_url_patterns(value)
@@ -534,6 +532,10 @@ def M(*patterns: Pattern, **lookups: Any) -> Pattern:
             lookup = Lookup(lookup_name) if lookup_name else None
             pattern = P(value, lookup=lookup)
 
+        # Skip patterns with no value, exept when using equal lookup
+        if not pattern.value and pattern.lookup is not Lookup.EQUAL:
+            continue
+
         patterns += (pattern,)
 
     # Combine and merge patterns
@@ -545,7 +547,7 @@ def M(*patterns: Pattern, **lookups: Any) -> Pattern:
 
 
 def get_scheme_port(scheme: Optional[str]) -> Optional[int]:
-    return {"http": 80, "https": 443}.get(scheme)
+    return {"http": 80, "https": 443}.get(scheme or "")
 
 
 def combine(
@@ -596,7 +598,7 @@ def parse_url_patterns(
     return bases
 
 
-def merge_patterns(pattern: Pattern, **bases: Pattern) -> Pattern:
+def merge_patterns(pattern: Optional[Pattern], **bases: Pattern) -> Optional[Pattern]:
     if not bases:
         return pattern
 
@@ -606,7 +608,7 @@ def merge_patterns(pattern: Pattern, **bases: Pattern) -> Pattern:
 
         if "host" in (_pattern.key for _pattern in patterns):
             # Pattern is "absolute", skip merging
-            bases = None
+            bases = {}
         else:
             # Traverse pattern and set related base
             for _pattern in patterns:
@@ -619,7 +621,7 @@ def merge_patterns(pattern: Pattern, **bases: Pattern) -> Pattern:
     if bases:
         # Combine left over base patterns with pattern
         base_pattern = combine(list(bases.values()))
-        if pattern:
+        if pattern and base_pattern:
             pattern = base_pattern & pattern
         else:
             pattern = base_pattern
