@@ -1,6 +1,6 @@
 import inspect
 from contextlib import contextmanager
-from functools import update_wrapper
+from functools import partial, update_wrapper, wraps
 from types import TracebackType
 from typing import (
     Any,
@@ -102,7 +102,7 @@ class Router:
         if any(not route.called for route in self.routes):
             raise AllCalledAssertionError("RESPX: some routes were not called!")
 
-    def __getitem__(self, name: str) -> Route:
+    def __getitem__(self, name: str) -> Optional[Route]:
         return self.routes[name]
 
     @overload
@@ -283,7 +283,9 @@ class Router:
                     resolved.response = cast(ResolvedResponseTypes, prospect)
                     break
 
-        if isinstance(resolved.response.stream, httpx.ByteStream):
+        if resolved.response and isinstance(
+            resolved.response.stream, httpx.ByteStream  # type: ignore[has-type]
+        ):
             resolved.response.read()  # Pre-read stream
 
         return resolved
@@ -296,7 +298,7 @@ class Router:
                 # Await async side effect and wrap any exception
                 if inspect.isawaitable(prospect):
                     try:
-                        prospect = await prospect  # type: ignore
+                        prospect = await prospect
                     except Exception as error:
                         raise SideEffectError(route, origin=error) from error
 
@@ -305,7 +307,9 @@ class Router:
                     resolved.response = cast(ResolvedResponseTypes, prospect)
                     break
 
-        if isinstance(resolved.response.stream, httpx.ByteStream):
+        if resolved.response and isinstance(
+            resolved.response.stream, httpx.ByteStream  # type: ignore[has-type]
+        ):
             await resolved.response.aread()  # Pre-read stream
 
         return resolved
@@ -322,8 +326,6 @@ class Router:
 
 
 class MockRouter(Router):
-    Mocker: Optional[Type[Mocker]]
-
     def __init__(
         self,
         *,
@@ -337,6 +339,7 @@ class MockRouter(Router):
             assert_all_mocked=assert_all_mocked,
             base_url=base_url,
         )
+        self.Mocker: Optional[Type[Mocker]] = None
         self._using = using
 
     @overload
@@ -379,7 +382,7 @@ class MockRouter(Router):
         for global state, i.e. shared patterns added outside of scope.
         """
         if func is None:
-            # Parantheses used, branch out to new nested instance.
+            # Parentheses used, branch out to new nested instance.
             # - Only stage when using local ctx `with respx.mock(...) as respx_mock:`
             # - First stage when using local decorator `@respx.mock(...)`
             #   FYI, global ctx `with respx.mock:` hits __enter__ directly
@@ -395,33 +398,36 @@ class MockRouter(Router):
             return respx_mock
 
         # Determine if decorated function needs a `respx_mock` instance
+        is_async = inspect.iscoroutinefunction(func)
         argspec = inspect.getfullargspec(func)
         needs_mock_reference = "respx_mock" in argspec.args
 
+        if needs_mock_reference:
+            func = partial(func, respx_mock=self)
+
         # Async Decorator
-        async def async_decorator(*args, **kwargs):
+        async def _async_decorator(*args, **kwargs):
             assert func is not None
-            if needs_mock_reference:
-                kwargs["respx_mock"] = self
             async with self:
                 return await func(*args, **kwargs)
 
         # Sync Decorator
-        def sync_decorator(*args, **kwargs):
+        def _sync_decorator(*args, **kwargs):
             assert func is not None
-            if "respx_mock" in argspec.args:
-                kwargs["respx_mock"] = self
             with self:
                 return func(*args, **kwargs)
 
-        if not needs_mock_reference:
-            async_decorator = update_wrapper(async_decorator, func)
-            sync_decorator = update_wrapper(sync_decorator, func)
+        if needs_mock_reference:
+            async_decorator = wraps(func)(_async_decorator)
+            sync_decorator = wraps(func)(_sync_decorator)
+        else:
+            async_decorator = update_wrapper(_async_decorator, func)
+            sync_decorator = update_wrapper(_sync_decorator, func)
 
-        # Dispatch async/sync decorator, depening on decorated function.
+        # Dispatch async/sync decorator, depending on decorated function.
         # - Only stage when using global decorator `@respx.mock`
         # - Second stage when using local decorator `@respx.mock(...)`
-        return async_decorator if inspect.iscoroutinefunction(func) else sync_decorator
+        return async_decorator if is_async else sync_decorator
 
     def __enter__(self) -> "MockRouter":
         self.start()
@@ -429,9 +435,9 @@ class MockRouter(Router):
 
     def __exit__(
         self,
-        exc_type: Type[BaseException] = None,
-        exc_value: BaseException = None,
-        traceback: TracebackType = None,
+        exc_type: Optional[Type[BaseException]] = None,
+        exc_value: Optional[BaseException] = None,
+        traceback: Optional[TracebackType] = None,
     ) -> None:
         self.stop(quiet=bool(exc_type is not None))
 
@@ -461,7 +467,7 @@ class MockRouter(Router):
         Register transport, snapshot router and start patching.
         """
         self.snapshot()
-        self.Mocker = Mocker.registry.get(self.using)
+        self.Mocker = Mocker.registry.get(self.using or "")
         if self.Mocker:
             self.Mocker.register(self)
             self.Mocker.start()
